package com.huijy.management.mapper;

import java.util.List;
import java.util.Map;

import com.huijy.management.domain.Content;

/**
 * 内容管理Mapper接口
 *
 * @author luobo
 * @date 2021-09-12
 */
public interface ContentMapper
{
    /**
     * 查询内容管理
     *
     * @param contentId 内容管理主键
     * @return 内容管理
     */
    public Content selectContentByContentId(Long contentId);

    /**
     * 查询内容管理列表
     *
     * @param content 内容管理
     * @return 内容管理集合
     */
    public List<Content> selectContentList(Content content);

    /**
     * 新增内容管理
     *
     * @param content 内容管理
     * @return 结果
     */
    public int insertContent(Content content);

    /**
     * 修改内容管理
     *
     * @param content 内容管理
     * @return 结果
     */
    public int updateContent(Content content);

    /**
     * 删除内容管理
     *
     * @param contentId 内容管理主键
     * @return 结果
     */
    public int deleteContentByContentId(Long contentId);

    /**
     * 批量删除内容管理
     *
     * @param contentIds 需要删除的数据主键集合
     * @return 结果
     */
    public int deleteContentByContentIds(Long[] contentIds);

    /**
     * 更新点击量
     * @param contentId
     * @return
     */
    public Integer updateBrowseNumById(Long contentId);

    public List<Map<String, Object>> home();


}
